Name: mod_nss
Version: 1.0.8
Release: 3%{?dist}
Summary: SSL/TLS module for the Apache HTTP server
Group: System Environment/Daemons
License: ASL 2.0
URL: http://directory.fedoraproject.org/wiki/Mod_nss
Source: http://directory.fedoraproject.org/sources/%{name}-%{version}.tar.gz
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires: nspr-devel, nss-devel >= 3.12.6
BuildRequires: httpd-devel, apr-devel, apr-util-devel
BuildRequires: pkgconfig
Requires(pre): httpd
Requires: nss >= 3.12.6
Requires: nss-tools
# Change configuration to not conflict with mod_ssl
Patch1: mod_nss-conf.patch
# Generate a password-less NSS database
Patch2: mod_nss-gencert.patch
# Properly set blocking status when no data is available
Patch3: mod_nss-wouldblock.patch
# Add options for new negotation API
Patch4: mod_nss-negotiate.patch
Patch5: mod_nss-reverseproxy.patch
Patch6: mod_nss-PK11_ListCerts.patch
Patch7: mod_nss-reseterror.patch

%description
The mod_nss module provides strong cryptography for the Apache Web
server via the Secure Sockets Layer (SSL) and Transport Layer
Security (TLS) protocols using the Network Security Services (NSS)
security library.

%prep
%setup -q
%patch1 -p1 -b .conf
%patch2 -p1 -b .gencert
%patch3 -p1 -b .wouldblock
%patch4 -p1 -b .negotiate
%patch5 -p1 -b .reverseproxy
%patch6 -p1 -b .PK11_ListCerts
%patch7 -p1 -b .reseterror

# Touch expression parser sources to prevent regenerating it
touch nss_expr_*.[chyl]

%build

CFLAGS="$RPM_OPT_FLAGS"
export CFLAGS

NSPR_INCLUDE_DIR=`/usr/bin/pkg-config --variable=includedir nspr`
NSPR_LIB_DIR=`/usr/bin/pkg-config --variable=libdir nspr`

NSS_INCLUDE_DIR=`/usr/bin/pkg-config --variable=includedir nss`
NSS_LIB_DIR=`/usr/bin/pkg-config --variable=libdir nss`

%configure \
    --with-nss-lib=$NSS_LIB_DIR \
    --with-nss-inc=$NSS_INCLUDE_DIR \
    --with-nspr-lib=$NSPR_LIB_DIR \
    --with-nspr-inc=$NSPR_INCLUDE_DIR \
    --with-apr-config --enable-ecc

make %{?_smp_mflags} all

%install
# The install target of the Makefile isn't used because that uses apxs
# which tries to enable the module in the build host httpd instead of in
# the build root.
rm -rf $RPM_BUILD_ROOT

mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/httpd/conf
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/httpd/conf.d
mkdir -p $RPM_BUILD_ROOT%{_libdir}/httpd/modules
mkdir -p $RPM_BUILD_ROOT%{_sbindir}
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/httpd/alias

install -m 644 nss.conf $RPM_BUILD_ROOT%{_sysconfdir}/httpd/conf.d/
install -m 755 .libs/libmodnss.so $RPM_BUILD_ROOT%{_libdir}/httpd/modules/
install -m 755 nss_pcache $RPM_BUILD_ROOT%{_sbindir}/
install -m 755 gencert $RPM_BUILD_ROOT%{_sbindir}/
ln -s ../../../%{_libdir}/libnssckbi.so $RPM_BUILD_ROOT%{_sysconfdir}/httpd/alias/
touch $RPM_BUILD_ROOT%{_sysconfdir}/httpd/alias/secmod.db
touch $RPM_BUILD_ROOT%{_sysconfdir}/httpd/alias/cert8.db
touch $RPM_BUILD_ROOT%{_sysconfdir}/httpd/alias/key3.db
touch $RPM_BUILD_ROOT%{_sysconfdir}/httpd/alias/install.log

%clean
rm -rf $RPM_BUILD_ROOT

%post
umask 077

if [ "$1" -eq 1 ] ; then
    if [ ! -e %{_sysconfdir}/httpd/alias/key3.db ]; then
        %{_sbindir}/gencert %{_sysconfdir}/httpd/alias > %{_sysconfdir}/httpd/alias/install.log 2>&1
    fi

    # Make sure that the database ownership is setup properly.
    /usr/bin/find %{_sysconfdir}/httpd/alias -user root -name "*.db" -exec %{__chgrp} apache {} \;
    /usr/bin/find %{_sysconfdir}/httpd/alias -user root -name "*.db" -exec %{__chmod} g+r {} \;
fi

%files
%defattr(-,root,root,-)
%doc README LICENSE docs/mod_nss.html
%config(noreplace) %{_sysconfdir}/httpd/conf.d/nss.conf
%{_libdir}/httpd/modules/libmodnss.so
%dir %{_sysconfdir}/httpd/alias/
%ghost %attr(0640,root,apache) %config(noreplace) %{_sysconfdir}/httpd/alias/secmod.db
%ghost %attr(0640,root,apache) %config(noreplace) %{_sysconfdir}/httpd/alias/cert8.db
%ghost %attr(0640,root,apache) %config(noreplace) %{_sysconfdir}/httpd/alias/key3.db
%ghost %config(noreplace) %{_sysconfdir}/httpd/alias/install.log
%{_sysconfdir}/httpd/alias/libnssckbi.so
%{_sbindir}/nss_pcache
%{_sbindir}/gencert

%changelog
* Mon Dec 13 2010 Rob Crittenden <rcritten@redhat.com> - 1.0.8-3
- Bump version to make upgrading from product-specific versions seamless
  (#588858)

* Wed Sep 22 2010 Rob Crittenden <rcritten@redhat.com> - 1.0.8-2
- Don't call PK11_ListCerts for every server (#635324)
- Fix hang when handling large POST under some conditions (#634685)

* Wed Jun  9 2010 Rob Crittenden <rcritten@redhat.com> - 1.0.8-1
- Rebase to upstream mod_nss 1.0.8 (#588858)
- Use remote hostname set by mod_proxy to compare to CN in peer cert (#591901)
- Patch to add configuration options for new NSS negotiation API (#574187)
- Set minimum version of nss to 3.12.6 to pick up renegotiation fix
- Add (pre) for Requires on httpd so we can be sure the user and group are
  already available
- Use _sysconfdir macro instead of /etc
- Remove unused variable and perl substitution for gencert. gencert used to
  have separate variables for NSS & NSPR libraries, that is gone now so this
  variable and substitution aren't needed.
- Added comments to patch to identify what they do
- The location of libnssckbi.so moved from /lib[64] to /usr/lib[64] (#558545)
- Don't generate output when the default NSS database is generated (#538859)

* Wed May 13 2009 Rob Crittenden <rcritten@redhat.com> 1.0.3-8
- Handle read blocking properly (#484380)

* Wed Jan 21 2009 Rob Crittenden <rcritten@redhat.com> 1.0.3-7
- Backport PassphraseDialog directive 'defer' (#489013)

* Thu Jul 24 2008 Rob Crittenden <rcritten@redhat.com> 1.0.3-6
- Register functions needed by mod_proxy if mod_ssl is not loaded (#338401)

* Tue Jul 01 2008 Rob Crittenden <rcritten@redhat.com> 1.0.3-5
- Include patch to fix NSSFIPS mode (#450349)

* Fri Aug 04 2006 Rob Crittenden <rcritten@redhat.com> 1.0.3-4
- Include LogLevel warn in nss.conf.

* Fri Aug 04 2006 Rob Crittenden <rcritten@redhat.com> 1.0.3-3
- Need to initialize ECC certificate and key variables

* Fri Aug 04 2006 Jarod Wilson <jwilson@redhat.com> 1.0.3-2
- Use %%ghost for db files and install.log

* Tue Jun 20 2006 Rob Crittenden <rcritten@redhat.com> 1.0.3-1
- Initial build
